<?php
/**
 * Prelude Lite Theme Customizer.
 * @package Prelude Lite
 */

function prelude_lite_customizer_registers() {
	
	wp_enqueue_script( 'prelude_lite_customizer_script', get_template_directory_uri() . '/js/prelude-lite-customizer.js', array("jquery"), '1.0', true  );
	wp_localize_script( 'prelude_lite_customizer_script', 'preludeliteCustomizerObject', array(
		'setup' => __( 'Setup Tutorials', 'prelude-lite' ),
		'support' => __( 'Theme Support', 'prelude-lite' ),
		'review' => __( 'Please Rate Prelude Lite', 'prelude-lite' ),		
		'pro' => __( 'Get the Pro Version', 'prelude-lite' ),
	) );
}
add_action( 'customize_controls_enqueue_scripts', 'prelude_lite_customizer_registers' );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function prelude_lite_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	
	
	// lets move the background colour to the background image section
	$wp_customize->get_control( 'background_color' )->section = 'background_image';

// BEGIN THEME OPTIONS

// Setting group for logo spacing	
    $wp_customize->add_setting( 'logo_padding',  array(
            'sanitize_callback' => 'absint',
            'default'           => '3',
        ) );
    $wp_customize->add_control( 'logo_padding', array(
        'type'        => 'number',
        'section'     => 'title_tagline',
		'label'    => __( 'Logo Left &amp; Right Padding', 'prelude-lite' ),
		'description' => __( 'When using a logo, use this setting to adjust the left and right spacing (padding) in percent. Default size is 3 (for 3%).', 'prelude-lite' ),
        'input_attrs' => array(
            'min'   => 0,
            'max'   => 100,
            'step'  => 1,
        ),
    ) );	

 
 // ADD SITE OPTIONS SECTION   
	$wp_customize->add_section( 'site_options', array(
		'title' => __( 'Site Options', 'prelude-lite' ),
		'priority'       => 30,
	) ); 

// Setting group for header style  
	$wp_customize->add_setting( 'header_style', array(
		'default' => 'header1',
		'sanitize_callback' => 'prelude_lite_sanitize_headerstyle',
	) );  
	$wp_customize->add_control( 'header_style', array(
		  'type' => 'radio',
		  'label' => __( 'Header Style', 'prelude-lite' ),
		  'section' => 'site_options',
		  'choices' => array(	
				'header1' => __( 'Header Style 1', 'prelude-lite' ),	
		) ) );	

	
// Setting group for boxed styles
	$wp_customize->add_setting( 'boxed_style', array(
		'default' => 'boxedfull',
		'sanitize_callback' => 'prelude_lite_sanitize_boxedstyle',
	) );  
	$wp_customize->add_control( 'boxed_style', array(
		  'type' => 'radio',
		  'label' => __( 'Boxed Style', 'prelude-lite' ),
		'description' => __( 'This will create a centered boxed layout of your page content for larger screens that can accommodate high resolutions and will show more of the page background.', 'prelude-lite' ),
		  'section' => 'site_options',
		  'choices' => array(	
				'boxedfull' => __( 'Full Width', 'prelude-lite' ),	 
				'boxed1300' => __( 'Boxed Width 1300px', 'prelude-lite' ), 
				'boxed1400' => __( 'Boxed Width 1400px', 'prelude-lite' ),
				'boxed1500' => __( 'Boxed Width 1500px', 'prelude-lite' ),
		) ) );		

// Setting group for boxed margins	
    $wp_customize->add_setting( 'boxed_margins',  array(
            'sanitize_callback' => 'absint',
            'default'           => '0',
        ) );
    $wp_customize->add_control( 'boxed_margins', array(
        'type'        => 'number',
        'section'     => 'site_options',
		'label'    => __( 'Page Top &amp; Bottom Space', 'prelude-lite' ),
		'description' => __( 'This will adjust the top and bottom space (margin) of your boxed layout. Enter in a number to represent pixels. Example: 20.', 'prelude-lite' ),
        'input_attrs' => array(
            'min'   => 0,
            'max'   => 100,
            'step'  => 1,
        ),
    ) );	


// Setting group for content area padding space	
    $wp_customize->add_setting( 'content_padding',  array(
            'sanitize_callback' => 'absint',
            'default'           => '60',
        ) );
    $wp_customize->add_control( 'content_padding', array(
        'type'        => 'number',
        'section'     => 'site_options',
		'label'    => esc_html__( 'Content Top &amp; Bottom Space', 'prelude-lite' ),
		'description' => __( 'This will adjust the top and bottom space (padding) of your main content area. Enter in a number to represent pixels. Example: 60.', 'prelude-lite' ),
        'input_attrs' => array(
            'min'   => 0,
            'max'   => 100,
            'step'  => 1,
        ),
    ) );	
// Setting group for left column size
	$wp_customize->add_setting( 'page_left_column_size',	array(
 		'default' => 0,
		'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
	) );  
	$wp_customize->add_control( 'page_left_column_size', array(
		'type'     => 'checkbox',
		'label'    => __( 'Use Smaller Left Sidebar Column', 'prelude-lite' ),
		'description' => __( 'This setting will change your left sidebar width when using templates with a left sidebar only. This will also make your main content area wider.', 'prelude-lite' ),
		'section'  => 'site_options',
  	) );
	
// Setting group to enable animation
	$wp_customize->add_setting( 'load_animation',	array(
 		'default' => 1,
		'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
	) );  
	$wp_customize->add_control( 'load_animation', array(
		'type'     => 'checkbox',
		'label'    => __( 'Load Animation Styles', 'prelude-lite' ),
		'description' => __( 'Load animation styles if not you are not using the Animate It plugin.', 'prelude-lite' ),
		'section'  => 'site_options',
  	) );
	
// Setting group to enable font awesome 
	$wp_customize->add_setting( 'load_fontawesome',	array(
 		'default' => 1,
		'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
	) );  
	$wp_customize->add_control( 'load_fontawesome', array(
		'type'     => 'checkbox',
		'label'    => __( 'Load Font Awesome', 'prelude-lite' ),
		'description' => __( 'Load Font Awesome if not you are not using a plugin for it.', 'prelude-lite' ),
		'section'  => 'site_options',
  	) );	
	
// Setting group to enable bootstrap
	$wp_customize->add_setting( 'load_bootstrap',	array(
		'default' => 1,
		'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
	) );  
	$wp_customize->add_control( 'load_bootstrap', array(
		'type'     => 'checkbox',
		'label'    => __( 'Load Bootstrap CSS', 'prelude-lite' ),
		'description' => __( 'Load the Bootstrap grid layout and some limited CSS elements if nothing else is loading it for you.', 'prelude-lite' ),
		'section'  => 'site_options',
	) );

// Setting group to show the edit links 
	  $wp_customize->add_setting( 'show_edit',  array(
		  'default' => 0,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'show_edit', array(
		'type'     => 'checkbox',
		'label'    => __( 'Show Edit Link', 'prelude-lite' ),
		'description' => __( 'Show the Edit Link on posts and pages.', 'prelude-lite' ),
		'section'  => 'site_options',
	  ) );	
	  
// Setting group for a Copyright
	$wp_customize->add_setting( 'copyright', array(
		'default'        => esc_html__( 'Your Name', 'prelude-lite' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wp_customize->add_control( 'copyright', array(
		'settings' => 'copyright',
		'label'    => esc_html__( 'Your Copyright Name', 'prelude-lite' ),
		'section'  => 'site_options',		
		'type'     => 'text',
	) );  
	
// ADD NEW SECTION CALLED BLOG OPTIONS 
	$wp_customize->add_section( 'blog_options', array(
		'title' => __( 'Blog Options', 'prelude-lite' ),
		'priority'       => 32,
	) ); 

	// Setting group for blog layout  
	$wp_customize->add_setting( 'blog_style', array(
		'default' => 'blog1',
		'sanitize_callback' => 'prelude_lite_sanitize_blogstyle',
	) );  
	$wp_customize->add_control( 'blog_style', array(
		  'type' => 'radio',
		  'label' => __( 'Blog Style', 'prelude-lite' ),
		  'section' => 'blog_options',
		  'choices' => array(	
				'blog1' => __( 'Standard with Right Sidebar', 'prelude-lite' ),	 
				'blog2' => __( 'Standard with Left Sidebar', 'prelude-lite' ), 
				'blog3' => __( 'Wide with no Sidebars', 'prelude-lite' ),
		) ) );

	// Setting group for single layout  
	$wp_customize->add_setting( 'single_style', array(
		'default' => 'single1',
		'sanitize_callback' => 'prelude_lite_sanitize_singlestyle',
	) );  
	$wp_customize->add_control( 'single_style', array(
		  'type' => 'radio',
		  'label' => __( 'Single Full Post Style', 'prelude-lite' ),
		  'section' => 'blog_options',
		  'choices' => array(	
				'single1' => __( 'Single with Right Sidebar', 'prelude-lite' ),	 
				'single2' => __( 'Single with Left Sidebar', 'prelude-lite' ),
		) ) );			

	 // Use excerpt 
	  $wp_customize->add_setting( 'use_excerpt',  array(
		  'default' => 0,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'use_excerpt', array(
		'type'     => 'checkbox',
		'label'    => __( 'Use Blog Excerpts', 'prelude-lite' ),
		'description' => __( 'This lets you switch to using excerpts for your blog summaries when using one of the first two blog styles.', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );	
	  
	// Setting group for a excerpt
    $wp_customize->add_setting( 'excerpt_length',  array(
            'sanitize_callback' => 'absint',
            'default'           => '50',
        ) );
    $wp_customize->add_control( 'excerpt_length', array(
        'type'        => 'number',
        'section'     => 'blog_options',
		'label'    => __( 'Excerpt Length', 'prelude-lite' ),
		'description' => __( 'This will adjust the number of words in your excerpt. Default is set to 50.', 'prelude-lite' ),
        'input_attrs' => array(
            'min'   => 1,
            'max'   => 100,
            'step'  => 1,
        ),
    ) );

	 // center blog summaries
	  $wp_customize->add_setting( 'center_blog_summaries',  array(
		  'default' => 0,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'center_blog_summaries', array(
		'type'     => 'checkbox',
		'label'    => __( 'Center Blog Summaries', 'prelude-lite' ),
		'description' => __( 'This lets you center your blog summary content in the blog 1, 2, and 3 styles. ', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );	  
// Setting group for left column size
	$wp_customize->add_setting( 'left_column_size',	array(
 		'default' => 0,
		'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
	) );  
	$wp_customize->add_control( 'left_column_size', array(
		'type'     => 'checkbox',
		'label'    => __( 'Blog Small Left Sidebar Column', 'prelude-lite' ),
		'description' => __( 'This setting will change your blog left sidebar column to be smaller and widen your main content column area.', 'prelude-lite' ),
		'section'  => 'blog_options',
  	) );	    
	  
	 // Show the post summary meta info 
	  $wp_customize->add_setting( 'show_summary_meta',  array(
		  'default' => 1,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'show_summary_meta', array(
		'type'     => 'checkbox',
		'label'    => __( 'Show Summary Meta Info', 'prelude-lite' ),
		'description' => __( 'Show the post summary meta info like the date, author, etc.', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );	

	 // Show the featured tag
	  $wp_customize->add_setting( 'show_featured_tag',  array(
		  'default' => 1,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'show_featured_tag', array(
		'type'     => 'checkbox',
		'label'    => __( 'Show Summary Featured Tag', 'prelude-lite' ),
		'description' => __( 'Show the featured (Sticky) tag on post summaries.', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );	

	 // Show the rounded post date 
	  $wp_customize->add_setting( 'show_round_postdate',  array(
		  'default' => 1,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'show_round_postdate', array(
		'type'     => 'checkbox',
		'label'    => __( 'Show the Summary Round Post Date', 'prelude-lite' ),
		'description' => __( 'Show the rounded post date on all blog posts.', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );	
	  
	 // Show the post date 
	  $wp_customize->add_setting( 'show_postdate',  array(
		  'default' => 1,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'show_postdate', array(
		'type'     => 'checkbox',
		'label'    => __( 'Show Summary Post Date', 'prelude-lite' ),
		'description' => __( 'Show the post date on all blog articles.', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );	 
	  
	 // Show the post author 
	  $wp_customize->add_setting( 'show_postauthor',  array(
		  'default' => 1,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'show_postauthor', array(
		'type'     => 'checkbox',
		'label'    => __( 'Show Summary Post Author', 'prelude-lite' ),
		'description' => __( 'Show the post author on all blog articles.', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );

	 // Show the post comments count on the summary 
	  $wp_customize->add_setting( 'show_commentslink',  array(
		  'default' => 1,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'show_commentslink', array(
		'type'     => 'checkbox',
		'label'    => __( 'Show Summary Comments Link', 'prelude-lite' ),
		'description' => __( 'Show the comments link on the post summaries.', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );


	 // Show the single categories list
	  $wp_customize->add_setting( 'show_categories',  array(
		  'default' => 1,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'show_categories', array(
		'type'     => 'checkbox',
		'label'    => __( 'Show Categories', 'prelude-lite' ),
		'description' => __( 'Show the categories list on the full post view.', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );

	 // Show the single tags list
	  $wp_customize->add_setting( 'show_tags',  array(
		  'default' => 1,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'show_tags', array(
		'type'     => 'checkbox',
		'label'    => __( 'Show Tags', 'prelude-lite' ),
		'description' => __( 'Show the tags list on the full post view.', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );

	  // Show the single post nav
	  $wp_customize->add_setting( 'show_postnav',  array(
		  'default' => 1,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'show_postnav', array(
		'type'     => 'checkbox',
		'label'    => __( 'Show Post Navigation', 'prelude-lite' ),
		'description' => __( 'Show the next previous navigation on the full post view.', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );
	  
	 // Show the single author bio
	  $wp_customize->add_setting( 'show_authorbio',  array(
		  'default' => 1,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'show_authorbio', array(
		'type'     => 'checkbox',
		'label'    => __( 'Show Author Bio', 'prelude-lite' ),
		'description' => __( 'Show the author bio information at the bottom of the full post view.', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );

	// Setting group to show footer info on single
	  $wp_customize->add_setting( 'show_single_footer',   array(
		  'default' => 1,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		)
	  );  
	  $wp_customize->add_control( 'show_single_footer', array(
		'type'     => 'checkbox',
		'label'    => __( 'Show Full Post Footer Information', 'prelude-lite' ),
		'description' => __( 'Show the footer information such as tags, categories, and anything else all at once.', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );	
	  
	// Setting group to show featured image on single
	  $wp_customize->add_setting( 'show_single_featured',   array(
		  'default' => 1,
		  'sanitize_callback' => 'prelude_lite_sanitize_checkbox',
		)
	  );  
	  $wp_customize->add_control( 'show_single_featured', array(
		'type'     => 'checkbox',
		'label'    => __( 'Show Full Post Featured Image', 'prelude-lite' ),
		'description' => __( 'Show the Featured Image on the full post view.', 'prelude-lite' ),
		'section'  => 'blog_options',
	  ) );	


	  
 // ADD TO COLOURS SECTION

	
// logo background
 	$wp_customize->add_setting( 'logo_bg', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'logo_bg', array(
		'label'   => __( 'Site Title &amp; Logo Background Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'logo_bg',
	) ) );		
	
// nav social background
 	$wp_customize->add_setting( 'site_header_bg', array(
		'default'        => '#151515',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'site_header_bg', array(
		'label'   => __( 'Header Background Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'site_header_bg',
	) ) );

  // site title
 	$wp_customize->add_setting( 'site_title', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'site_title', array(
		'label'   => __( 'Site Title Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'site_title',
	) ) ); 
	
 // content background
 	$wp_customize->add_setting( 'content_bg', array(
		'default'        => '#f3f3f3',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'content_bg', array(
		'label'   => __( 'Content Area Background Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'content_bg',
	) ) ); 
 	
 // post block background
 	$wp_customize->add_setting( 'post_summary_bg', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'post_summary_bg', array(
		'label'   => __( 'Post Summary Background Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'post_summary_bg',
	) ) );

  // post summary title 
	$wp_customize->add_setting( 'post_summary_title', array(
		'default'        => '#191919',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'post_summary_title', array(
		'label'   => __( 'Post Summary Title Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'post_summary_title',
	) ) );  

  // post summary title hover
	$wp_customize->add_setting( 'post_summary_hover_title', array(
		'default'        => '#c17676',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'post_summary_hover_title', array(
		'label'   => __( 'Post Summary Hover Title Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'post_summary_hover_title',
	) ) );
	
   // post summary meta
 	$wp_customize->add_setting( 'post_summary_meta', array(
		'default'        => '#949393',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'post_summary_meta', array(
		'label'   => __( 'Post Summary Meta Info Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'post_summary_meta',
	) ) ); 	
 // post summary text
	$wp_customize->add_setting( 'post_summary_text', array(
		'default'        => '#595c61',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'post_summary_text', array(
		'label'   => __( 'Post Summary Text Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'post_summary_text',
	) ) );  

  // date circle
	$wp_customize->add_setting( 'date_circle', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'date_circle', array(
		'label'   => __( 'Post Summary Date Background', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'date_circle',
	) ) ); 
 
   // date text
	$wp_customize->add_setting( 'date_text', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'date_text', array(
		'label'   => __( 'Post Summary Date Text', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'date_text',
	) ) );

// featured background	
 	$wp_customize->add_setting( 'featured_bg', array(
		'default'        => '#3b3c3e',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'featured_bg', array(
		'label'   => __( 'Featured Label background', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'featured_bg',
	) ) );
// featured text	
 	$wp_customize->add_setting( 'featured_text', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'featured_text', array(
		'label'   => __( 'Featured Text Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'featured_text',
	) ) );
	
    // read more
	$wp_customize->add_setting( 'read_more_text', array(
		'default'        => '#949393',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'read_more_text', array(
		'label'   => __( 'Post Summary Continue Reading Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'read_more_text',
	) ) );
	
    // read more hover
	$wp_customize->add_setting( 'read_more_hover', array(
		'default'        => '#595c61',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'read_more_hover', array(
		'label'   => __( 'Post Summary Continue Reading Hover Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'read_more_hover',
	) ) );	

    // read more lines
	$wp_customize->add_setting( 'read_more_line', array(
		'default'        => '#e0e0e0',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'read_more_line', array(
		'label'   => __( 'Post Summary Continue Reading Line', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'read_more_line',
	) ) );	
		 
  // title headings
	$wp_customize->add_setting( 'page_headings', array(
		'default'        => '#191919',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'page_headings', array(
		'label'   => __( 'Page Title Headings Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'page_headings',
	) ) ); 	
 // page content text
	$wp_customize->add_setting( 'page_text_colour', array(
		'default'        => '#595c61',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'page_text_colour', array(
		'label'   => __( 'Page Text Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'page_text_colour',
	) ) );  

   // links
	$wp_customize->add_setting( 'links', array(
		'default'        => '#c17676',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'links', array(
		'label'   => __( 'Link Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'links',
	) ) ); 
 
    // hover links
	$wp_customize->add_setting( 'hover_links', array(
		'default'        => '#595c61',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'hover_links', array(
		'label'   => __( 'Link Hover Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'hover_links',
	) ) );
 
    // blockquote text
	$wp_customize->add_setting( 'blockquote_text', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blockquote_text', array(
		'label'   => __( 'Blockquote &amp; Inline Quote Text', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'blockquote_text',
	) ) ); 

    // blockquote
	$wp_customize->add_setting( 'blockquote', array(
		'default'        => '#3b3c3e',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blockquote', array(
		'label'   => __( 'Blockquote Punctuation Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'blockquote',
	) ) );	
	
    // dropcap
	$wp_customize->add_setting( 'dropcap', array(
		'default'        => '#595c61',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dropcap', array(
		'label'   => __( 'Dropcap Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'dropcap',
	) ) );	
	
    // display heading
	$wp_customize->add_setting( 'display_heading', array(
		'default'        => '#191919',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'display_heading', array(
		'label'   => __( 'Display Heading Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'display_heading',
	) ) );		

    // display subheading
	$wp_customize->add_setting( 'display_subheading', array(
		'default'        => '#8b8d92',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'display_subheading', array(
		'label'   => __( 'Display Sub Heading Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'display_subheading',
	) ) );		

  // dividers
	$wp_customize->add_setting( 'divider_colour', array(
		'default'        => '#ccc',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'divider_colour', array(
		'label'   => __( 'Page Divider Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'divider_colour',
	) ) );	
 
  // single background
 	$wp_customize->add_setting( 'single_bg', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'single_bg', array(
		'label'   => __( 'Full Post Background Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'single_bg',
	) ) ); 
 
  // single post navigation colour
 	$wp_customize->add_setting( 'single_nav_colour', array(
		'default'        => '#595c61',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'single_nav_colour', array(
		'label'   => __( 'Full Post Navigation Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'single_nav_colour',
	) ) );  
 
  // comment name colour
 	$wp_customize->add_setting( 'comment_name', array(
		'default'        => '#595c61',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'comment_name', array(
		'label'   => __( 'Comment Name Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'comment_name',
	) ) );   
 
  // comment reply colour
 	$wp_customize->add_setting( 'comment_reply', array(
		'default'        => '#9fa3a7',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'comment_reply', array(
		'label'   => __( 'Comment Reply Link Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'comment_reply',
	) ) );  
 
   // comment separator colour
 	$wp_customize->add_setting( 'comment_separator', array(
		'default'        => '#ededed',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'comment_separator', array(
		'label'   => __( 'Comment Separator Line', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'comment_separator',
	) ) ); 
 
   // left and right sidebar links
 	$wp_customize->add_setting( 'lr_sidebar_list_links', array(
		'default'        => '#595c61',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lr_sidebar_list_links', array(
		'label'   => __( 'Left &amp; Right List Links', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'lr_sidebar_list_links',
	) ) ); 
 
    // left and right sidebar links hover
 	$wp_customize->add_setting( 'lr_sidebar_list_hover_links', array(
		'default'        => '#c17676',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lr_sidebar_list_hover_links', array(
		'label'   => __( 'Left &amp; Right List Hover Links', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'lr_sidebar_list_hover_links',
	) ) ); 
 
  // left and right sidebar list borders
 	$wp_customize->add_setting( 'lr_sidebar_list_borders', array(
		'default'        => '#e6e6e6',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lr_sidebar_list_borders', array(
		'label'   => __( 'Left &amp; Right List Borders', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'lr_sidebar_list_borders',
	) ) ); 
 
  // left and right sidebar tag background
 	$wp_customize->add_setting( 'lr_sidebar_tag_bg', array(
		'default'        => '#e6e6e6',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lr_sidebar_tag_bg', array(
		'label'   => __( 'Left &amp; Right Tag Background', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'lr_sidebar_tag_bg',
	) ) );  
 
  // left and right sidebar tag background hover
 	$wp_customize->add_setting( 'lr_sidebar_tag_text', array(
		'default'        => '#000',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lr_sidebar_tag_text', array(
		'label'   => __( 'Left &amp; Right Tag Text', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'lr_sidebar_tag_text',
	) ) );  
 
   // bottom sidebars background colour
 	$wp_customize->add_setting( 'bottom_sidebar_bg', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'bottom_sidebar_bg', array(
		'label'   => __( 'Bottom Sidebar Background', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'bottom_sidebar_bg',
	) ) );
  // bottom sidebars text colour
 	$wp_customize->add_setting( 'bottom_sidebar_text', array(
		'default'        => '#f1d8d8',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'bottom_sidebar_text', array(
		'label'   => __( 'Bottom Sidebar Text', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'bottom_sidebar_text',
	) ) );  
 
   // bottom sidebars list link colour hover
 	$wp_customize->add_setting( 'bottom_sidebar_list_link_hover', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'bottom_sidebar_list_link_hover', array(
		'label'   => __( 'Bottom Sidebar List Hover Links', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'bottom_sidebar_list_link_hover',
	) ) ); 
 
    // bottom sidebars list borders
 	$wp_customize->add_setting( 'bottom_sidebar_list_borders', array(
		'default'        => '#ab7272',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'bottom_sidebar_list_borders', array(
		'label'   => __( 'Bottom Sidebar List Borders', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'bottom_sidebar_list_borders',
	) ) ); 
 
    // bottom sidebars tag background
 	$wp_customize->add_setting( 'bottom_sidebar_tag_bg', array(
		'default'        => '#151515',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'bottom_sidebar_tag_bg', array(
		'label'   => __( 'Bottom Sidebar Tag Background', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'bottom_sidebar_tag_bg',
	) ) );  
 
    // bottom sidebars tag text
 	$wp_customize->add_setting( 'bottom_sidebar_tag_text', array(
		'default'        => '#f3f3f3',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'bottom_sidebar_tag_text', array(
		'label'   => __( 'Bottom Sidebar Tag Text', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'bottom_sidebar_tag_text',
	) ) );  
 
 // image viewer nav
 	$wp_customize->add_setting( 'attachment_nav', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'attachment_nav', array(
		'label'   => __( 'Image Attachment Navigation Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'attachment_nav',
	) ) );	
 
  // image viewer hover nav
 	$wp_customize->add_setting( 'attachment_hover_nav', array(
		'default'        => '#151515',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'attachment_hover_nav', array(
		'label'   => __( 'Image Attachment Navigation Hover Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'attachment_hover_nav',
	) ) );	
 
 
	
// button colour
 	$wp_customize->add_setting( 'button_colour', array(
		'default'        => '#474747',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'button_colour', array(
		'label'   => __( 'Button Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'button_colour',
	) ) );			
	
// button text colour
 	$wp_customize->add_setting( 'button_text_colour', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'button_text_colour', array(
		'label'   => __( 'Button Text Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'button_text_colour',
	) ) );	
	
// button hover colour
 	$wp_customize->add_setting( 'button_hover_colour', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'button_hover_colour', array(
		'label'   => __( 'Button Hover Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'button_hover_colour',
	) ) );		
	
// button text hover colour
 	$wp_customize->add_setting( 'button_text_hover_colour', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'button_text_hover_colour', array(
		'label'   => __( 'Button Hover Text Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'button_text_hover_colour',
	) ) );		
 
 // button border colour
 	$wp_customize->add_setting( 'button_border_colour', array(
		'default'        => '#474747',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'button_border_colour', array(
		'label'   => __( 'Button Border Style', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'button_border_colour',
	) ) );	
 
  // button border colour
 	$wp_customize->add_setting( 'button_border_hover_colour', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'button_border_hover_colour', array(
		'label'   => __( 'Button Border Hover Style', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'button_border_hover_colour',
	) ) );	
 
  // form input border colour
 	$wp_customize->add_setting( 'input_border', array(
		'default'        => '#b8b8b8',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'input_border', array(
		'label'   => __( 'Input Field Border', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'input_border',
	) ) );	 
 
   // form input border focus colour
 	$wp_customize->add_setting( 'input_focus_border', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'input_focus_border', array(
		'label'   => __( 'Input Field Focus Border on Click', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'input_focus_border',
	) ) );
 
    // contact form input background focus colour
 	$wp_customize->add_setting( 'input_focus_contact_bg', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'input_focus_contact_bg', array(
		'label'   => __( 'Contact Form Field Background on Click', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'input_focus_contact_bg',
	) ) );
 
     // contact form input text focus colour
 	$wp_customize->add_setting( 'input_focus_contact_text', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'input_focus_contact_text', array(
		'label'   => __( 'Contact Form Field Text on Click', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'input_focus_contact_text',
	) ) );
 
 // header sidebar text
 	$wp_customize->add_setting( 'header_sidebar_text', array(
		'default'        => '#c9c9c9',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_sidebar_text', array(
		'label'   => __( 'Header Sidebar Text', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'header_sidebar_text',
	) ) );  
 
 // footer text
 	$wp_customize->add_setting( 'footer_text', array(
		'default'        => '#919191',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_text', array(
		'label'   => __( 'Footer Text Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'footer_text',
	) ) );   
 
 // footer hover links
 	$wp_customize->add_setting( 'footer_hover_links', array(
		'default'        => '#ccc',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_hover_links', array(
		'label'   => __( 'Footer Hover Link Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'footer_hover_links',
	) ) );   
 
 // back to top background
 	$wp_customize->add_setting( 'back_top', array(
		'default'        => '#000',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'back_top', array(
		'label'   => __( 'Back To Top Icon Background', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'back_top',
	) ) );

 // back to top icon
 	$wp_customize->add_setting( 'back_top_icon', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'back_top_icon', array(
		'label'   => __( 'Back To Top Icon', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'back_top_icon',
	) ) );

 // back to top icon
 	$wp_customize->add_setting( 'back_top_hover', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'back_top_hover', array(
		'label'   => __( 'Back To Top Background on Hover', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'back_top_hover',
	) ) );
	
 // banner border
 	$wp_customize->add_setting( 'banner_border', array(
		'default'        => '#000',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'banner_border', array(
		'label'   => __( 'Banner Bottom Border', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'banner_border',
	) ) );	
	
 // banner caption 1 colour
 	$wp_customize->add_setting( 'banner_caption1', array(
		'default'        => '#000',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'banner_caption1', array(
		'label'   => __( 'Banner Caption 1 Text', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'banner_caption1',
	) ) );		
	
 // banner caption 2 colour
 	$wp_customize->add_setting( 'banner_caption2', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'banner_caption2', array(
		'label'   => __( 'Banner Caption 2 Text', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'banner_caption2',
	) ) );	
	
 // banner caption button
 	$wp_customize->add_setting( 'banner_caption_button', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'banner_caption_button', array(
		'label'   => __( 'Banner Caption Button', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'banner_caption_button',
	) ) );

 // banner caption button text
 	$wp_customize->add_setting( 'banner_caption_button_text', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'banner_caption_button_text', array(
		'label'   => __( 'Banner Caption Button Text', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'banner_caption_button_text',
	) ) );

 // banner caption button text
 	$wp_customize->add_setting( 'banner_caption_button_hover', array(
		'default'        => '#474747',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'banner_caption_button_hover', array(
		'label'   => __( 'Banner Caption Button Hover', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'banner_caption_button_hover',
	) ) );

 // banner caption button hover text
 	$wp_customize->add_setting( 'banner_caption_button_text_hover', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'banner_caption_button_text_hover', array(
		'label'   => __( 'Banner Caption Button Hover Text', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'banner_caption_button_text_hover',
	) ) );



// mobile menu button
 	$wp_customize->add_setting( 'mobile_button', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mobile_button', array(
		'label'   => __( 'Mobile Menu Button Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'mobile_button',
	) ) ); 
// mobile menu button text
 	$wp_customize->add_setting( 'mobile_button_text', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mobile_button_text', array(
		'label'   => __( 'Mobile Menu Button Text Colour', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'mobile_button_text',
	) ) ); 
 
 // mobile menu button text
 	$wp_customize->add_setting( 'mobile_button_text', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mobile_button_text', array(
		'label'   => __( 'Mobile Menu Button Text', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'mobile_button_text',
	) ) ); 
	
 // mobile menu button hover
 	$wp_customize->add_setting( 'mobile_button_hover', array(
		'default'        => '#464646',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mobile_button_hover', array(
		'label'   => __( 'Mobile Menu Button Hover', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'mobile_button_hover',
	) ) ); 	
	
 // mobile menu button text hover
 	$wp_customize->add_setting( 'mobile_button_text_hover', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mobile_button_text_hover', array(
		'label'   => __( 'Mobile Menu Button Text Hover', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'mobile_button_text_hover',
	) ) ); 	
	
 // mobile menu background hover
 	$wp_customize->add_setting( 'mobile_menu_bg', array(
		'default'        => '#202020',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mobile_menu_bg', array(
		'label'   => __( 'Mobile Menu Background', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'mobile_menu_bg',
	) ) );	
	
 // mobile menu lines
 	$wp_customize->add_setting( 'mobile_menu_lines', array(
		'default'        => '#464646',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mobile_menu_lines', array(
		'label'   => __( 'Mobile Menu Lines', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'mobile_menu_lines',
	) ) );	
	
 // mobile menu links
 	$wp_customize->add_setting( 'mobile_menu_links', array(
		'default'        => '#c9c9c9',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mobile_menu_links', array(
		'label'   => __( 'Mobile Menu Links', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'mobile_menu_links',
	) ) );	
	
 // mobile menu hover links
 	$wp_customize->add_setting( 'mobile_menu_hover_active', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mobile_menu_hover_active', array(
		'label'   => __( 'Mobile Menu Hover &amp; Active Links', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'mobile_menu_hover_active',
	) ) );		
	
 // mobile menu submenu button
 	$wp_customize->add_setting( 'mobile_submenu_button', array(
		'default'        => '#464646',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mobile_submenu_button', array(
		'label'   => __( 'Mobile Submenu Button', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'mobile_submenu_button',
	) ) ); 		
 
 // mobile menu submenu button icon
 	$wp_customize->add_setting( 'mobile_submenu_button_icon', array(
		'default'        => '#7d7c7c',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mobile_submenu_button_icon', array(
		'label'   => __( 'Mobile Submenu Button Icon', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'mobile_submenu_button_icon',
	) ) ); 
 
  // main menu links
 	$wp_customize->add_setting( 'main_menu_links', array(
		'default'        => '#c9c9c9',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'main_menu_links', array(
		'label'   => __( 'Main Menu Links', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'main_menu_links',
	) ) ); 
  // main menu hover links
 	$wp_customize->add_setting( 'main_menu_hover_active', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'main_menu_hover_active', array(
		'label'   => __( 'Main Menu Hover &amp; Active Links', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'main_menu_hover_active',
	) ) );  
 
  // main menu hover links
 	$wp_customize->add_setting( 'main_menu_hover_active_bg', array(
		'default'        => '#3b3c3e',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'main_menu_hover_active_bg', array(
		'label'   => __( 'Main Menu Hover &amp; Active Background', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'main_menu_hover_active_bg',
	) ) );  
 
  // main menu submenu background
 	$wp_customize->add_setting( 'main_submenu_arrow', array(
		'default'        => '#202020',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'main_submenu_arrow', array(
		'label'   => __( 'Main Submenu Arrow', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'main_submenu_arrow',
	) ) );   
 
   // social menu icon
 	$wp_customize->add_setting( 'social_icon', array(
		'default'        => '#c9c9c9',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'social_icon', array(
		'label'   => __( 'Social Icon', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'social_icon',
	) ) ); 
 
   // social  icon background
 	$wp_customize->add_setting( 'social_icon_bg', array(
		'default'        => '#3b3c3e',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'social_icon_bg', array(
		'label'   => __( 'Social Icon Background', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'social_icon_bg',
	) ) );  
 
    // social  icon hover
 	$wp_customize->add_setting( 'social_icon_hover', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'social_icon_hover', array(
		'label'   => __( 'Social Icon Hover', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'social_icon_hover',
	) ) );  
		
    // multi-page nav
 	$wp_customize->add_setting( 'multi_page_bg', array(
		'default'        => '#ccc',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'multi_page_bg', array(
		'label'   => __( 'Multi-Page Nav Background', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'multi_page_bg',
	) ) ); 

    // multi-page nav text
 	$wp_customize->add_setting( 'multi_page_text', array(
		'default'        => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'multi_page_text', array(
		'label'   => __( 'Multi-Page Nav Text', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'multi_page_text',
	) ) ); 

    // multi-page nav active hover
 	$wp_customize->add_setting( 'multi_page_active', array(
		'default'        => '#a05252',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'multi_page_active', array(
		'label'   => __( 'Multi-Page Active &amp; Hover', 'prelude-lite' ),
		'section' => 'colors',
		'settings'   => 'multi_page_active',
	) ) ); 

		
// ADD A TYPOGRAPHY SECTION
  $wp_customize->add_section( 'typography_options', array(
      'title' => __( 'Typography Options', 'prelude-lite' ),
	  'description' => __('This theme is setup to use Google Fonts and the Raleway font is the default font for headings. You can use these typography settings or use a font plugin for more flexibility.', 'prelude-lite'),
	  'priority' => 83,
    )  ); 
	
// Setting group to show the site title  
  	$wp_customize->add_setting( 'load_cyrillic_subset',  array(
		'default' => 0,
		'sanitize_callback' => 'prelude_lite_sanitize_checkbox'
   	 ) );  
 	 $wp_customize->add_control( 'load_cyrillic_subset', array(
		'type'     => 'checkbox',
		'section'  => 'typography_options',
		'label'    => __( 'Load Cyrillic Font Subsets', 'prelude-lite' ),
		'description' => __( 'If you need the Cyrillic font subsets loaded for the included Google Fonts of Raleway and your custom fonts, then check this box.', 'prelude-lite' ),
 	 ) );	
 
// Setting group for the main body font
	$wp_customize->add_setting( 'second_google_font', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wp_customize->add_control( 'second_google_font', array(
		'settings' => 'second_google_font',
		'label'    => __( 'Add a Second Google Font', 'prelude-lite' ),
		'description' => __( 'This will add a second Google font to your website.', 'prelude-lite' ),
		'section'  => 'typography_options',		
		'type'     => 'text',
	) );

// Setting group for the heading font
	$wp_customize->add_setting( 'third_google_font', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wp_customize->add_control( 'third_google_font', array(
		'settings' => 'third_google_font',
		'label'    => __( 'Add a Third Google Font', 'prelude-lite' ),
		'description' => __( 'This will add a third Google Font to your website.', 'prelude-lite' ),
		'section'  => 'typography_options',		
		'type'     => 'text',
	) );	 
			
// Setting group for the Site Title font size
	$wp_customize->add_setting( 'site_title_size', array(
		'default'        => '2',
		'sanitize_callback' => 'prelude_lite_sanitize_decimals',
	) );
	$wp_customize->add_control( 'site_title_size', array(
		'settings' => 'site_title_size',
		'label'    => esc_html__( 'Site Title Font Size', 'prelude-lite' ),
		'description' => __( 'This will change the site title font size in rem units. By default, the site title is using 2rem as the size, so you would enter in: 2 in this field.', 'prelude-lite' ),
		'section'  => 'typography_options',		
		'type'     => 'text',
	) );		
		
// Setting group for the main content font size
	$wp_customize->add_setting( 'main_content_size', array(
		'default'        => '0.875',
		'sanitize_callback' => 'prelude_lite_sanitize_decimals',
	) );
	$wp_customize->add_control( 'main_content_size', array(
		'settings' => 'main_content_size',
		'label'    => esc_html__( 'Content Font Size', 'prelude-lite' ),
		'description' => __( 'This will change the main content area font size in rem units. By default, the site title is using 0.875 as the size, so you would enter in: 0.875 in this field.', 'prelude-lite' ),
		'section'  => 'typography_options',		
		'type'     => 'text',
	) );			
		
// Setting group for the widget font size
	$wp_customize->add_setting( 'font_size_widgets', array(
		'default'        => '0.813',
		'sanitize_callback' => 'prelude_lite_sanitize_decimals',
	) );
	$wp_customize->add_control( 'font_size_widgets', array(
		'settings' => 'font_size_widgets',
		'label'    => esc_html__( 'Widget Font Size', 'prelude-lite' ),
		'description' => __( 'This will change the widget text font size in rem units. By default, the site title is using 0.813rem as the size, so you would enter in: 0.813 in this field.', 'prelude-lite' ),
		'section'  => 'typography_options',		
		'type'     => 'text',
	) );		
		
// Setting group for the widget title font size
	$wp_customize->add_setting( 'font_size_widget_title', array(
		'default'        => '1.125',
		'sanitize_callback' => 'prelude_lite_sanitize_decimals',
	) );
	$wp_customize->add_control( 'font_size_widget_title', array(
		'settings' => 'font_size_widget_title',
		'label'    => esc_html__( 'Widget Title Font Size', 'prelude-lite' ),
		'description' => __( 'This will change the widget title font size in rem units. By default, the site title is using 1.125rem as the size, so you would enter in: 1.125 in this field.', 'prelude-lite' ),
		'section'  => 'typography_options',		
		'type'     => 'text',
	) );		
	
// Setting group for the blog entry title font size
	$wp_customize->add_setting( 'blog_entry_title_size', array(
		'default'        => '1.5',
		'sanitize_callback' => 'prelude_lite_sanitize_decimals',
	) );
	$wp_customize->add_control( 'blog_entry_title_size', array(
		'settings' => 'blog_entry_title_size',
		'label'    => esc_html__( 'Blog Summary Title Font Size', 'prelude-lite' ),
		'description' => __( 'This will change the blog summary title font size in rem units. By default, the site title is using 1.5rem as the size, so you would enter in: 1.5 in this field.', 'prelude-lite' ),
		'section'  => 'typography_options',		
		'type'     => 'text',
	) );
	
// Setting group for the main menu font size
	$wp_customize->add_setting( 'menu_font_size', array(
		'default'        => '0.938',
		'sanitize_callback' => 'prelude_lite_sanitize_decimals',
	) );
	$wp_customize->add_control( 'menu_font_size', array(
		'settings' => 'menu_font_size',
		'label'    => esc_html__( 'Main Menu Font Size', 'prelude-lite' ),
		'description' => __( 'This will change the main menu font size in rem units. By default, the site title is using 0.938rem as the size, so you would enter in: 0.938 in this field.', 'prelude-lite' ),
		'section'  => 'typography_options',		
		'type'     => 'text',
	) );

// Setting group for the submenu font size
	$wp_customize->add_setting( 'submenu_font_size', array(
		'default'        => '0.875',
		'sanitize_callback' => 'prelude_lite_sanitize_decimals',
	) );
	$wp_customize->add_control( 'submenu_font_size', array(
		'settings' => 'submenu_font_size',
		'label'    => esc_html__( 'SubMenu Font Size', 'prelude-lite' ),
		'description' => __( 'This will change the submenu font size in rem units. By default, the site title is using 0.875rem as the size, so you would enter in: 0.875 in this field.', 'prelude-lite' ),
		'section'  => 'typography_options',		
		'type'     => 'text',
	) );

	
// ADD TO THE BACKGROUND IMAGE SECTION

	$wp_customize->add_setting( 'bgsize', array(
		'default' => 'initial',
		'sanitize_callback' => 'prelude_lite_sanitize_bgsize',
	) );  
	$wp_customize->add_control( 'bgsize', array(
		  'type' => 'radio',
		  'label' => __( 'Background Image Size', 'prelude-lite' ),
		  'section' => 'background_image',
		  'priority' => 20,
		  'choices' => array(	
				'initial' => __( 'Initial', 'prelude-lite' ),
				'auto' => __( 'Auto', 'prelude-lite' ),	 
				'cover' => __( 'Cover', 'prelude-lite' ), 
				'contain' => __( 'Contain', 'prelude-lite' ),
		) ) );		 
 

	
// END THEME OPTIONS	
}



add_action( 'customize_register', 'prelude_lite_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function prelude_lite_customize_preview_js() {
	wp_enqueue_script( 'prelude_lite_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'prelude_lite_customize_preview_js' );




// BEGIN SANITATION

// adds sanitization callback function : checkbox
if ( ! function_exists( 'prelude_lite_sanitize_checkbox' ) ) :
	function prelude_lite_sanitize_checkbox( $input ) {
		if ( $input == 1 ) {
			return 1;
		} else {
			return '';
		}
	}	 
endif;

// adds sanitization callback function for numeric data : decimals
if ( ! function_exists( 'prelude_lite_sanitize_decimals' ) ) :
function prelude_lite_sanitize_decimals( $input ) {
	$decimal = floatval( $input );
	return $decimal;
}
endif;


// adds sanitization callback function for background image size
if ( ! function_exists( 'prelude_lite_sanitize_bgsize' ) ) :
  function prelude_lite_sanitize_bgsize( $value ) {
    $bgsize = array( 'initial','auto', 'cover', 'contain' );
    if ( ! in_array( $value, $bgsize ) ) {
      $value = 'initial';
    }
    return $value;
  }
endif;

// adds sanitization callback function for header style
if ( ! function_exists( 'prelude_lite_sanitize_headerstyle' ) ) :
  function prelude_lite_sanitize_headerstyle( $value ) {
    $header_style = array( 'header1' );
    if ( ! in_array( $value, $header_style ) ) {
      $value = 'header1';
    }
    return $value;
  }
endif;

// adds sanitization callback function for boxed style
if ( ! function_exists( 'prelude_lite_sanitize_boxedstyle' ) ) :
  function prelude_lite_sanitize_boxedstyle( $value ) {
    $boxed_style = array( 'boxedfull', 'boxed1300', 'boxed1400', 'boxed1500' );
    if ( ! in_array( $value, $boxed_style ) ) {
      $value = 'boxedfull';
    }
    return $value;
  }
endif;
// adds sanitization callback function for blog style
if ( ! function_exists( 'prelude_lite_sanitize_blogstyle' ) ) :
  function prelude_lite_sanitize_blogstyle( $value ) {
    $blog_style = array( 'blog1', 'blog2', 'blog3' );
    if ( ! in_array( $value, $blog_style ) ) {
      $value = 'blog1';
    }
    return $value;
  }
endif;

// adds sanitization callback function for single style
if ( ! function_exists( 'prelude_lite_sanitize_singlestyle' ) ) :
  function prelude_lite_sanitize_singlestyle( $value ) {
    $single_style = array( 'single1', 'single2' );
    if ( ! in_array( $value, $single_style ) ) {
      $value = 'single1';
    }
    return $value;
  }
endif;
